PALM-meteo: palmmeteo.logging Namespace Reference

PALM-meteo

Functions | Variables
palmmeteo.logging Namespace Reference

## Functions
def | die (s, *args, **kwargs)
def | warn (s, *args, **kwargs)
def | log_on (s, *args, **kwargs)
def | log_off (s, *args, **kwargs)
def | configure_log (cfg)

## Variables
| log_output = sys.stdout.write
| error_output = sys.stderr.write
def | log = log_on
def | verbose = log_off

## Function Documentation

## ◆ configure_log()

def palmmeteo.logging.configure_log | ( |  | cfg | ) |

## ◆ die()

def palmmeteo.logging.die | ( |  | s,
|  | * | args,
|  | ** | kwargs
| ) |  |

    Write message to error output and exit with status 1.

## ◆ log_off()

def palmmeteo.logging.log_off | ( |  | s,
|  | * | args,
|  | ** | kwargs
| ) |  |

    Do nothing (logging is disabled).

## ◆ log_on()

def palmmeteo.logging.log_on | ( |  | s,
|  | * | args,
|  | ** | kwargs
| ) |  |

    Write logging or debugging message to standard output (logging is enabled).

## ◆ warn()

def palmmeteo.logging.warn | ( |  | s,
|  | * | args,
|  | ** | kwargs
| ) |  |

    Write message to error output.

## Variable Documentation

## ◆ error_output

palmmeteo.logging.error_output = sys.stderr.write

## ◆ log

def palmmeteo.logging.log = log_on

## ◆ log_output

palmmeteo.logging.log_output = sys.stdout.write

## ◆ verbose

def palmmeteo.logging.verbose = log_off